==> pkgsearch-1.0.6.tar.gz: pkgsearch-1.0.6/src/pkgsearch.h <==
/* Copyright (c) 2007, 2008, Diego_Rocha
* All rights reserved.
*
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions are met:
*     * Redistributions of source code must retain the above copyright
*       notice, this list of conditions and the following disclaimer.
*     * Redistributions in binary form must reproduce the above copyright
*       notice, this list of conditions and the following disclaimer in the
*       documentation and/or other materials provided with the distribution.
*     * Neither the name of the Diego_Rocha nor the
*       names of its contributors may be used to endorse or promote products
*       derived from this software without specific prior written permission.
*
* THIS SOFTWARE IS PROVIDED BY COPYRIGHT ``AS IS'' AND ANY
* EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
* DISCLAIMED. IN NO EVENT SHALL COPYRIGHT BE LIABLE FOR ANY
* DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
* (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
* LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
* ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
* (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
* SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE
*
* Author: Diego_Rocha <diegorocha1987@gmail.com>
*
*/

#ifndef PKGSEARCH_H
#define PKGSEARCH_H

#include <sys/types.h>
#include <sys/stat.h>
#include <sys/param.h>
#include <dirent.h>

#include <errno.h>
#include <stdio.h>
#include <unistd.h>
#include <string.h>
#include <stdlib.h>

#ifndef ABORT
#define ABORT(msg) { (void)fprintf( stderr, "Error: %s %s\n",msg, strerror(errno)); exit( 1 ); }
#endif

#define PORTS "/usr/ports"
#define PKG "/var/db/pkg"

//#define MAKEFILE "Makefile"
#define INFO "distinfo"

#if defined (__OpenBSD__)
#define DESC "pkg/DESCR"
#else
#define DESC "pkg-descr"
#endif

#define PKGDESC "/+DESC"

#define INDEXPORT ".portindex.txt"
#define INDEXPKG ".pkgindex.txt"

#define VERSION "1.0.6"

#define MAXLINELEN 1024

int uflag, dflag, sflag, iflag;
char *home;

int simple_getline( char*, size_t, FILE* );

int make_index_ports(void);
int make_index_pkg(void);

int search_ports(char*);
int search_pkg(char*);

int show_desc(char*);
int show_size(char*);

void usage();
void help();
void version();

#endif

==> pkgsearch-1.1.0.tar.gz: pkgsearch-1.1.0/src/pkgsearch.h <==
/* Copyright (c) 2007, 2008, Diego_Rocha
* All rights reserved.
*
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions are met:
*     * Redistributions of source code must retain the above copyright
*       notice, this list of conditions and the following disclaimer.
*     * Redistributions in binary form must reproduce the above copyright
*       notice, this list of conditions and the following disclaimer in the
*       documentation and/or other materials provided with the distribution.
*     * Neither the name of the Diego_Rocha nor the
*       names of its contributors may be used to endorse or promote products
*       derived from this software without specific prior written permission.
*
* THIS SOFTWARE IS PROVIDED BY COPYRIGHT ``AS IS'' AND ANY
* EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
* DISCLAIMED. IN NO EVENT SHALL COPYRIGHT BE LIABLE FOR ANY
* DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
* (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
* LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
* ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
* (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
* SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE
*
* Author: Diego_Rocha <diegorocha1987@gmail.com>
*
*/

#ifndef PKGSEARCH_H
#define PKGSEARCH_H

#ifndef ABORT
#define ABORT(msg) 																  \
	do{ 																		  \
		(void)fprintf( stderr, "Error: %s %s\n",msg, strerror(errno)); 			  \
		exit( 1 ); 																  \
	}while(0)

#endif

#ifndef __GNUC__
#  define  __attribute__(x)  /*NOTHING*/
#endif

#define PORTS "/usr/ports"
#define PKG "/var/db/pkg"

//#define MAKEFILE "Makefile"
#define INFO "distinfo"

#if defined (__OpenBSD__)
#define DESC "pkg/DESCR"
#else
#define DESC "pkg-descr"
#endif

#define PKGDESC "/+DESC"

#define INDEXPORT ".portindex.txt"
#define INDEXPKG ".pkgindex.txt"

#define VERSION "1.1.1"

#define MAXLINELEN 1024

extern int regex_func( char*, char* );
extern int simple_getline( char*, size_t, FILE* );
extern int make_index_ports(void);
extern int make_index_pkg(void);
extern int search_ports(char*);
extern int search_pkg(char*);
extern int show_desc(char*);
extern int show_size(char*);

extern void usage() __attribute__((noreturn));
extern void help() __attribute__((noreturn));
extern void version() __attribute__((noreturn));

#endif
